@@ -24,7 +24,11 @@ sub SHOW_CURSOR () { "\e[?25h" }
 sub wrapper_get {
     my ( $opt, $url ) = @_;
     my $show_progress = 1;
-    my $ua = LWP::UserAgent->new( agent => $opt->{useragent}, timeout => $opt->{timeout}, show_progress => $show_progress );
+    my $ua = LWP::UserAgent->new(
+        agent         => $opt->{useragent},
+        timeout       => $opt->{timeout},
+        show_progress => $show_progress
+    );
     my $res;
     my $count = 1;
     RETRY: while ( 1 ) {
