@@ -11,8 +11,10 @@ our @EXPORT_OK = qw( download_youtube );
 use Fcntl          qw( LOCK_EX SEEK_END );
 use File::Basename qw( basename );
 use Time::HiRes    qw( gettimeofday tv_interval );
+use Time::Local    qw( timelocal );
 
 use Encode::Locale   qw();
+use File::Touch      qw();
 use LWP::UserAgent   qw();
 use Term::ANSIScreen qw( :cursor :screen );
 use Try::Tiny        qw( try catch );
@@ -38,6 +40,13 @@ sub download_youtube {
             my $file_name_OS = encode_fs( $info->{$video_id}{file_name} );
             unlink $file_name_OS or die $! if -f $file_name_OS && $opt->{overwrite};
             _download_video( $opt, $info, $ua, $video_id );
+            if ( $opt->{upload_date_is_file_date} ) {
+                if ( $info->{$video_id}{upload_date} =~ /^(\d\d\d\d)-(\d\d)-(\d\d)\z/ ) {
+                    my $time = timelocal( 0, 0, 0, $3, $2 - 1, $1 );
+                    my $ref = File::Touch->new( time => $time );
+                    my $count = $ref->touch( $file_name_OS );
+                }
+            }
         }
         catch {
             say "$video_id - $_";
