@@ -12,12 +12,10 @@ use Encode qw( decode_utf8 );
 
 use Term::ANSIScreen qw( :cursor :screen );
 use Text::LineFold   qw();
-use URI              qw();
-use URI::Escape      qw( uri_unescape );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::Data         qw( wrapper_get get_download_info_as_json );
+use App::YTDL::Data         qw( get_download_info_as_json );
 use App::YTDL::Data_Extract qw( json_to_hash );
 use App::YTDL::Helper       qw( term_size );
 
@@ -28,19 +26,6 @@ sub _youtube_print_info {
     my $message = "** GET download info: ";
     my $json = get_download_info_as_json( $opt, $video_id, $message );
     json_to_hash( $json, $info ) if $json;
-    my $info_url = URI->new( 'https://www.youtube.com/get_video_info' );
-    $info_url->query_form( 'video_id' => $video_id );
-    my $res = wrapper_get( $opt, $info_url->as_string );
-    $opt->{up}++;
-    return if ! defined $res;
-    for my $item ( split /&/, $res->decoded_content ) {
-        my ( $key, $value ) = split /=/, $item;
-        if ( defined $value && $key =~ /^(?:title|keywords|reason|status)\z/ ) {
-            $info->{$video_id}{$key} = decode_utf8( uri_unescape( $value ) );
-            $info->{$video_id}{$key} =~ s/\+/ /g;
-            $info->{$video_id}{$key} =~ s/(?<=\p{Word}),(?=\p{Word})/, /g if $key eq 'keywords';
-        }
-    }
 }
 
 
@@ -57,14 +42,8 @@ sub _prepare_print_info {
         }
     }
     my @keys = ( qw( title video_id ) );
-    if ( defined $info->{$video_id}{status} && $info->{$video_id}{status} ne 'ok' ) {
-        $opt->{up}++;
-        print up( $opt->{up} ), cldown;
-        $opt->{up} = 0;
-        splice @keys, 1, 0, 'status', 'errorcode', 'reason';
-    }
-    push @keys, 'extractor' if $info->{$video_id}{extractor} !~ /^youtube\z/i;
-    push @keys, qw( author duration raters avg_rating view_count published content description keywords );
+    push @keys, 'extractor' if $info->{$video_id}{extractor} ne 'youtube';
+    push @keys, qw( author duration raters avg_rating view_count published description keywords ); # categories
     for my $key ( @keys ) {
         next if ! $info->{$video_id}{$key};
         $info->{$video_id}{$key} =~ s/\R/ /g;
