@@ -8,6 +8,7 @@ use 5.010000;
 use Exporter qw( import );
 our @EXPORT_OK = qw( from_arguments_to_choices );
 
+use JSON                   qw( decode_json );
 use List::MoreUtils        qw( any );
 use Term::ANSIScreen       qw( :cursor :screen );
 use Term::Choose           qw( choose );
@@ -16,7 +17,7 @@ use URI                    qw();
 use URI::Escape            qw( uri_unescape );
 
 use App::YTDL::Data         qw( wrapper_get get_download_info_as_json );
-use App::YTDL::Data_Extract qw( xml_to_entry_node add_entry_node_to_info_hash json_to_hash );
+use App::YTDL::Data_Extract qw( add_entry_to_info_hash json_to_hash );
 
 
 
@@ -157,9 +158,9 @@ sub _id_to_tmp_info_hash {
     my $tmp = {};
     my $start_index = 1;
     my $max_results = 50;
-    my $count_e_nodes = $max_results;
-    while ( $count_e_nodes == $max_results ) {  # or <link rel='next'>
-        $url->query_form( 'start-index' => $start_index, 'max-results' => $max_results, 'v' => $opt->{yt_api_v} );
+    my $count_entries = $max_results;
+    while ( $count_entries == $max_results ) {  # or <link rel='next'>
+        $url->query_form( 'start-index' => $start_index, 'max-results' => $max_results, 'v' => $opt->{yt_api_v}, 'alt' => 'json' );
         $start_index += $max_results;
         my $res = wrapper_get( $opt, $url->as_string );
         if ( ! defined $res ) {
@@ -167,14 +168,15 @@ sub _id_to_tmp_info_hash {
             push @{$opt->{error_get_download_infos}}, $err_msg;
             next;
         }
-        my $xml = $res->decoded_content;
-        my @e_nodes = xml_to_entry_node( $opt, $xml );
-        $count_e_nodes = @e_nodes;
-        if ( ! $count_e_nodes ) {
+        my $json = $res->decoded_content;
+        my $h_ref = decode_json( $json );
+        my $entries = $h_ref->{feed}{entry};
+        $count_entries = @$entries;
+        if ( ! $count_entries ) {
             last;
         }
-        for my $e_node ( @e_nodes ) {
-            add_entry_node_to_info_hash( $opt, $tmp, $e_node, $type, $list_id );
+        for my $entry ( @$entries ) {
+            add_entry_to_info_hash( $opt, $tmp, $entry, $type, $list_id ); #
         }
     }
     if ( ! keys %$tmp ) {
@@ -192,16 +194,17 @@ sub _more_url_to_tmp_info_hash {
     my $tmp = {};
     for my $video_id ( split /,/, $more_ids ) {
         my $url = URI->new( 'https://gdata.youtube.com/feeds/api/videos/' . $video_id );
-        $url->query_form( 'v' => $opt->{yt_api_v} );
+        $url->query_form( 'v' => $opt->{yt_api_v}, 'alt' => 'json' );
         my $res = wrapper_get( $opt, $url );
         if ( ! defined $res ) {
             my $err_msg = 'Video group: ' . $more_ids . ' - ' . $video_id . '   ' . $url;
             push @{$opt->{error_get_download_infos}}, $err_msg;
             next;
         }
-        my $xml = $res->decoded_content;
-        my ( $e_node ) = xml_to_entry_node( $opt, $xml );
-        add_entry_node_to_info_hash( $opt, $tmp, $e_node );
+        my $json = $res->decoded_content;
+        my $h_ref = decode_json( $json );
+        my $entry = $h_ref->{feed}{entry};
+        add_entry_to_info_hash( $opt, $tmp, $entry );
     }
     return $tmp;
 }
